Documentation
¶
Index ¶
- type APIToken
- type AuditLog
- type Client
- func (c *Client) ClearFlowReports(ctx context.Context) error
- func (c *Client) ClearRadioEvents(ctx context.Context) error
- func (c *Client) CreateBackup(ctx context.Context, p *CreateBackupParams) error
- func (c *Client) CreateDataNetwork(ctx context.Context, opts *CreateDataNetworkOptions) error
- func (c *Client) CreateMyAPIToken(ctx context.Context, opts *CreateAPITokenOptions) (*CreateAPITokenResponse, error)
- func (c *Client) CreatePolicy(ctx context.Context, opts *CreatePolicyOptions) error
- func (c *Client) CreateRoute(ctx context.Context, opts *CreateRouteOptions) error
- func (c *Client) CreateSubscriber(ctx context.Context, opts *CreateSubscriberOptions) error
- func (c *Client) CreateUser(ctx context.Context, opts *CreateUserOptions) error
- func (c *Client) CreateUserAPIToken(ctx context.Context, email string, opts *CreateAPITokenOptions) (*CreateAPITokenResponse, error)
- func (c *Client) DeleteDataNetwork(ctx context.Context, opts *DeleteDataNetworkOptions) error
- func (c *Client) DeleteMyAPIToken(ctx context.Context, tokenID string) error
- func (c *Client) DeletePolicy(ctx context.Context, opts *DeletePolicyOptions) error
- func (c *Client) DeleteRoute(ctx context.Context, opts *DeleteRouteOptions) error
- func (c *Client) DeleteSubscriber(ctx context.Context, opts *DeleteSubscriberOptions) error
- func (c *Client) DeleteUser(ctx context.Context, opts *DeleteUserOptions) error
- func (c *Client) DeleteUserAPIToken(ctx context.Context, email string, tokenID string) error
- func (c *Client) GenerateSupportBundle(ctx context.Context, p *GenerateSupportBundleParams) error
- func (c *Client) GetAuditLogRetentionPolicy(ctx context.Context) (*GetAuditLogsRetentionPolicy, error)
- func (c *Client) GetDataNetwork(ctx context.Context, opts *GetDataNetworkOptions) (*DataNetwork, error)
- func (c *Client) GetFlowReportStats(ctx context.Context, p *ListFlowReportsParams) (*FlowReportStatsResponse, error)
- func (c *Client) GetFlowReportsRetentionPolicy(ctx context.Context) (*GetFlowReportsRetentionPolicy, error)
- func (c *Client) GetMetrics(ctx context.Context) (map[string]float64, error)
- func (c *Client) GetNATInfo(ctx context.Context) (*GetNATInfoResponse, error)
- func (c *Client) GetOperator(ctx context.Context) (*Operator, error)
- func (c *Client) GetPolicy(ctx context.Context, opts *GetPolicyOptions) (*Policy, error)
- func (c *Client) GetRadio(ctx context.Context, opts *GetRadioOptions) (*Radio, error)
- func (c *Client) GetRadioEvent(ctx context.Context, id int) (*RadioEventContent, error)
- func (c *Client) GetRadioEventRetentionPolicy(ctx context.Context) (*GetRadioEventsRetentionPolicy, error)
- func (c *Client) GetRoute(ctx context.Context, opts *GetRouteOptions) (*Route, error)
- func (c *Client) GetStatus(ctx context.Context) (*Status, error)
- func (c *Client) GetSubscriber(ctx context.Context, opts *GetSubscriberOptions) (*SubscriberDetail, error)
- func (c *Client) GetSubscriberCredentials(ctx context.Context, opts *GetSubscriberCredentialsOptions) (*SubscriberCredentials, error)
- func (c *Client) GetToken() string
- func (c *Client) GetUsageRetentionPolicy(ctx context.Context) (*GetUsageRetentionPolicy, error)
- func (c *Client) Initialize(ctx context.Context, opts *InitializeOptions) error
- func (c *Client) ListAuditLogs(ctx context.Context, p *ListAuditLogsParams) (*ListAuditLogsResponse, error)
- func (c *Client) ListAuditLogsByActor(ctx context.Context, actor string, p *ListParams) (*ListAuditLogsResponse, error)
- func (c *Client) ListDataNetworks(ctx context.Context, p *ListParams) (*ListDataNetworksResponse, error)
- func (c *Client) ListFlowReports(ctx context.Context, p *ListFlowReportsParams) (*ListFlowReportsResponse, error)
- func (c *Client) ListFlowReportsByDay(ctx context.Context, p *ListFlowReportsParams) (*GroupedFlowReportsResponse, error)
- func (c *Client) ListFlowReportsBySubscriber(ctx context.Context, p *ListFlowReportsParams) (*GroupedFlowReportsResponse, error)
- func (c *Client) ListMyAPITokens(ctx context.Context, p *ListParams) (*ListAPITokensResponse, error)
- func (c *Client) ListPolicies(ctx context.Context, p *ListParams) (*ListPoliciesResponse, error)
- func (c *Client) ListRadioEvents(ctx context.Context, p *ListRadioEventsParams) (*ListRadioEventsResponse, error)
- func (c *Client) ListRadios(ctx context.Context, p *ListParams) (*ListRadiosResponse, error)
- func (c *Client) ListRoutes(ctx context.Context, p *ListParams) (*ListRoutesResponse, error)
- func (c *Client) ListSubscribers(ctx context.Context, p *ListParams) (*ListSubscribersResponse, error)
- func (c *Client) ListUsage(ctx context.Context, p *ListUsageParams) (*ListUsageResponse, error)
- func (c *Client) ListUserAPITokens(ctx context.Context, email string, p *ListParams) (*ListAPITokensResponse, error)
- func (c *Client) ListUsers(ctx context.Context, p *ListParams) (*ListUsersResponse, error)
- func (c *Client) Login(ctx context.Context, opts *LoginOptions) error
- func (c *Client) Refresh(ctx context.Context) error
- func (c *Client) RestoreBackup(ctx context.Context, p *RestoreBackupParams) error
- func (c *Client) SetToken(token string)
- func (c *Client) UpdateAuditLogRetentionPolicy(ctx context.Context, opts *UpdateAuditLogsRetentionPolicyOptions) error
- func (c *Client) UpdateFlowReportsRetentionPolicy(ctx context.Context, opts *UpdateFlowReportsRetentionPolicyOptions) error
- func (c *Client) UpdateNATInfo(ctx context.Context, opts *UpdateNATInfoOptions) error
- func (c *Client) UpdateOperatorHomeNetwork(ctx context.Context, opts *UpdateOperatorHomeNetworkOptions) error
- func (c *Client) UpdateOperatorID(ctx context.Context, opts *UpdateOperatorIDOptions) error
- func (c *Client) UpdateOperatorSlice(ctx context.Context, opts *UpdateOperatorSliceOptions) error
- func (c *Client) UpdateOperatorTracking(ctx context.Context, opts *UpdateOperatorTrackingOptions) error
- func (c *Client) UpdateRadioEventRetentionPolicy(ctx context.Context, opts *UpdateRadioEventsRetentionPolicyOptions) error
- func (c *Client) UpdateUsageRetentionPolicy(ctx context.Context, opts *UpdateUsageRetentionPolicyOptions) error
- type Config
- type ConnectionError
- type CreateAPITokenOptions
- type CreateAPITokenResponse
- type CreateBackupParams
- type CreateDataNetworkOptions
- type CreatePolicyOptions
- type CreateRouteOptions
- type CreateSubscriberOptions
- type CreateUserOptions
- type DataNetwork
- type DeleteDataNetworkOptions
- type DeletePolicyOptions
- type DeleteRouteOptions
- type DeleteSubscriberOptions
- type DeleteUserOptions
- type FlowReport
- type FlowReportIPStat
- type FlowReportProtocolStat
- type FlowReportStatsResponse
- type GenerateSupportBundleParams
- type GetAuditLogsRetentionPolicy
- type GetDataNetworkOptions
- type GetFlowReportsRetentionPolicy
- type GetNATInfoResponse
- type GetOperatorHomeNetworkResponse
- type GetOperatorIDResponse
- type GetOperatorSliceResponse
- type GetOperatorTrackingResponse
- type GetPolicyOptions
- type GetRadioEventsRetentionPolicy
- type GetRadioOptions
- type GetRouteOptions
- type GetSubscriberCredentialsOptions
- type GetSubscriberOptions
- type GetUsageRetentionPolicy
- type GroupedFlowReportsResponse
- type InitializeOptions
- type InitializeResponseResult
- type ListAPITokensResponse
- type ListAuditLogsParams
- type ListAuditLogsResponse
- type ListDataNetworksResponse
- type ListFlowReportsParams
- type ListFlowReportsResponse
- type ListParams
- type ListPoliciesResponse
- type ListRadioEventsParams
- type ListRadioEventsResponse
- type ListRadiosResponse
- type ListRoutesResponse
- type ListSubscribersResponse
- type ListUsageParams
- type ListUsageResponse
- type ListUsersResponse
- type LoginOptions
- type LoginResponseResult
- type Operator
- type PlmnID
- type Policy
- type Radio
- type RadioEvent
- type RadioEventContent
- type RefreshResponseResult
- type RequestError
- type RequestOptions
- type RequestResponse
- type RequestType
- type Requester
- type RestoreBackupParams
- type RoleID
- type Route
- type Snssai
- type Status
- type Subscriber
- type SubscriberCredentials
- type SubscriberDetail
- type SubscriberDetailStatus
- type SubscriberStatus
- type SubscriberUsage
- type SupportedTAI
- type Tai
- type UpdateAuditLogsRetentionPolicyOptions
- type UpdateFlowReportsRetentionPolicyOptions
- type UpdateNATInfoOptions
- type UpdateOperatorHomeNetworkOptions
- type UpdateOperatorIDOptions
- type UpdateOperatorSliceOptions
- type UpdateOperatorTrackingOptions
- type UpdateRadioEventsRetentionPolicyOptions
- type UpdateUsageRetentionPolicyOptions
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
Requester Requester
// contains filtered or unexported fields
}
A Client knows how to talk to the the Ella Core API.
func (*Client) ClearFlowReports ¶ added in v1.4.0
ClearFlowReports deletes all flow reports. Reports will be permanently deleted.
func (*Client) ClearRadioEvents ¶ added in v0.6.0
ClearRadioEvents clears all radio events. Events will be permanently deleted.
func (*Client) CreateBackup ¶ added in v1.1.0
func (c *Client) CreateBackup(ctx context.Context, p *CreateBackupParams) error
CreateBackup creates a backup and saves it to the specified path.
func (*Client) CreateDataNetwork ¶ added in v0.1.0
func (c *Client) CreateDataNetwork(ctx context.Context, opts *CreateDataNetworkOptions) error
CreateDataNetwork creates a new data network with the provided options.
func (*Client) CreateMyAPIToken ¶ added in v0.2.0
func (c *Client) CreateMyAPIToken(ctx context.Context, opts *CreateAPITokenOptions) (*CreateAPITokenResponse, error)
CreateMyAPIToken creates a new API token for the authenticated user.
func (*Client) CreatePolicy ¶ added in v0.1.0
func (c *Client) CreatePolicy(ctx context.Context, opts *CreatePolicyOptions) error
CreatePolicy creates a new policy with the provided options.
func (*Client) CreateRoute ¶
func (c *Client) CreateRoute(ctx context.Context, opts *CreateRouteOptions) error
CreateRoute creates a new route with the provided options. The route will be added to the system's underlying kernel routing table.
func (*Client) CreateSubscriber ¶
func (c *Client) CreateSubscriber(ctx context.Context, opts *CreateSubscriberOptions) error
CreateSubscriber creates a new subscriber with the provided options.
func (*Client) CreateUser ¶
func (c *Client) CreateUser(ctx context.Context, opts *CreateUserOptions) error
CreateUser creates a new user with the provided options.
func (*Client) CreateUserAPIToken ¶ added in v1.5.0
func (c *Client) CreateUserAPIToken(ctx context.Context, email string, opts *CreateAPITokenOptions) (*CreateAPITokenResponse, error)
CreateUserAPIToken creates a new API token for the specified user. Requires admin privileges.
func (*Client) DeleteDataNetwork ¶ added in v0.1.0
func (c *Client) DeleteDataNetwork(ctx context.Context, opts *DeleteDataNetworkOptions) error
DeleteDataNetwork deletes a data network by name.
func (*Client) DeleteMyAPIToken ¶ added in v0.2.0
DeleteMyAPIToken deletes an API token for the authenticated user by token ID.
func (*Client) DeletePolicy ¶ added in v0.1.0
func (c *Client) DeletePolicy(ctx context.Context, opts *DeletePolicyOptions) error
DeletePolicy deletes a policy by name.
func (*Client) DeleteRoute ¶
func (c *Client) DeleteRoute(ctx context.Context, opts *DeleteRouteOptions) error
DeleteRoute deletes a route by ID.
func (*Client) DeleteSubscriber ¶
func (c *Client) DeleteSubscriber(ctx context.Context, opts *DeleteSubscriberOptions) error
DeleteSubscriber deletes a subscriber by ID.
func (*Client) DeleteUser ¶
func (c *Client) DeleteUser(ctx context.Context, opts *DeleteUserOptions) error
DeleteUser deletes a user by email.
func (*Client) DeleteUserAPIToken ¶ added in v1.5.0
DeleteUserAPIToken deletes an API token for the specified user by token ID. Requires admin privileges.
func (*Client) GenerateSupportBundle ¶ added in v1.5.0
func (c *Client) GenerateSupportBundle(ctx context.Context, p *GenerateSupportBundleParams) error
GenerateSupportBundle requests a support bundle from the server and saves the returned gzipped tar to the provided path.
func (*Client) GetAuditLogRetentionPolicy ¶ added in v0.2.0
func (c *Client) GetAuditLogRetentionPolicy(ctx context.Context) (*GetAuditLogsRetentionPolicy, error)
GetAuditLogRetentionPolicy retrieves the current audit log retention policy.
func (*Client) GetDataNetwork ¶ added in v0.1.0
func (c *Client) GetDataNetwork(ctx context.Context, opts *GetDataNetworkOptions) (*DataNetwork, error)
GetDataNetwork retrieves the details of a data network by name.
func (*Client) GetFlowReportStats ¶ added in v1.4.0
func (c *Client) GetFlowReportStats(ctx context.Context, p *ListFlowReportsParams) (*FlowReportStatsResponse, error)
GetFlowReportStats retrieves aggregated flow report statistics.
func (*Client) GetFlowReportsRetentionPolicy ¶ added in v1.4.0
func (c *Client) GetFlowReportsRetentionPolicy(ctx context.Context) (*GetFlowReportsRetentionPolicy, error)
GetFlowReportsRetentionPolicy retrieves the current flow reports retention policy.
func (*Client) GetMetrics ¶
GetMetrics retrieves the metrics from the server and returns a map where keys are metric names and values are their corresponding float values.
func (*Client) GetNATInfo ¶ added in v0.3.0
func (c *Client) GetNATInfo(ctx context.Context) (*GetNATInfoResponse, error)
GetNATInfo retrieves the current Network Address Translation (NAT) configuration.
func (*Client) GetOperator ¶
GetOperator retrieves the current operator configuration.
func (*Client) GetRadioEvent ¶ added in v0.6.0
GetRadioEvent retrieves a radio event by ID.
func (*Client) GetRadioEventRetentionPolicy ¶ added in v0.6.0
func (c *Client) GetRadioEventRetentionPolicy(ctx context.Context) (*GetRadioEventsRetentionPolicy, error)
GetRadioEventRetentionPolicy retrieves the current radio event retention policy.
func (*Client) GetSubscriber ¶
func (c *Client) GetSubscriber(ctx context.Context, opts *GetSubscriberOptions) (*SubscriberDetail, error)
GetSubscriber retrieves a subscriber by ID.
func (*Client) GetSubscriberCredentials ¶ added in v1.5.0
func (c *Client) GetSubscriberCredentials(ctx context.Context, opts *GetSubscriberCredentialsOptions) (*SubscriberCredentials, error)
GetSubscriberCredentials retrieves the authentication credentials for a subscriber. requires Admin or Network Manager role.
func (*Client) GetUsageRetentionPolicy ¶ added in v0.6.0
func (c *Client) GetUsageRetentionPolicy(ctx context.Context) (*GetUsageRetentionPolicy, error)
GetUsageRetentionPolicy retrieves the current usage retention policy.
func (*Client) Initialize ¶ added in v0.4.0
func (c *Client) Initialize(ctx context.Context, opts *InitializeOptions) error
Initialize initializes the client with the provided options. On success, it stores the returned access token in the client.
func (*Client) ListAuditLogs ¶ added in v0.2.0
func (c *Client) ListAuditLogs(ctx context.Context, p *ListAuditLogsParams) (*ListAuditLogsResponse, error)
ListAuditLogs retrieves a paginated list of audit logs with optional filters.
func (*Client) ListAuditLogsByActor ¶ added in v1.5.0
func (c *Client) ListAuditLogsByActor(ctx context.Context, actor string, p *ListParams) (*ListAuditLogsResponse, error)
ListAuditLogsByActor retrieves a paginated list of audit logs filtered by actor email. Deprecated: Use ListAuditLogs with ListAuditLogsParams.Actor instead.
func (*Client) ListDataNetworks ¶ added in v0.1.0
func (c *Client) ListDataNetworks(ctx context.Context, p *ListParams) (*ListDataNetworksResponse, error)
ListDataNetworks lists all data networks with pagination support.
func (*Client) ListFlowReports ¶ added in v1.4.0
func (c *Client) ListFlowReports(ctx context.Context, p *ListFlowReportsParams) (*ListFlowReportsResponse, error)
ListFlowReports retrieves a paginated list of flow reports with optional filtering.
func (*Client) ListFlowReportsByDay ¶ added in v1.4.0
func (c *Client) ListFlowReportsByDay(ctx context.Context, p *ListFlowReportsParams) (*GroupedFlowReportsResponse, error)
ListFlowReportsByDay retrieves flow reports grouped by day.
func (*Client) ListFlowReportsBySubscriber ¶ added in v1.4.0
func (c *Client) ListFlowReportsBySubscriber(ctx context.Context, p *ListFlowReportsParams) (*GroupedFlowReportsResponse, error)
ListFlowReportsBySubscriber retrieves flow reports grouped by subscriber.
func (*Client) ListMyAPITokens ¶ added in v0.2.0
func (c *Client) ListMyAPITokens(ctx context.Context, p *ListParams) (*ListAPITokensResponse, error)
ListMyAPITokens lists API tokens for the authenticated user with pagination.
func (*Client) ListPolicies ¶ added in v0.1.0
func (c *Client) ListPolicies(ctx context.Context, p *ListParams) (*ListPoliciesResponse, error)
ListPolicies lists policies with pagination.
func (*Client) ListRadioEvents ¶ added in v0.6.0
func (c *Client) ListRadioEvents(ctx context.Context, p *ListRadioEventsParams) (*ListRadioEventsResponse, error)
ListRadioEvents lists radio events with filtering and pagination.
func (*Client) ListRadios ¶
func (c *Client) ListRadios(ctx context.Context, p *ListParams) (*ListRadiosResponse, error)
ListRadios lists radios with pagination.
func (*Client) ListRoutes ¶
func (c *Client) ListRoutes(ctx context.Context, p *ListParams) (*ListRoutesResponse, error)
ListRoutes lists routes with pagination.
func (*Client) ListSubscribers ¶
func (c *Client) ListSubscribers(ctx context.Context, p *ListParams) (*ListSubscribersResponse, error)
ListSubscribers lists subscribers with pagination.
func (*Client) ListUsage ¶ added in v0.6.0
func (c *Client) ListUsage(ctx context.Context, p *ListUsageParams) (*ListUsageResponse, error)
ListUsage retrieves subscriber usage data based on the provided parameters.
func (*Client) ListUserAPITokens ¶ added in v1.5.0
func (c *Client) ListUserAPITokens(ctx context.Context, email string, p *ListParams) (*ListAPITokensResponse, error)
ListUserAPITokens lists API tokens for a specific user with pagination. Requires admin privileges.
func (*Client) ListUsers ¶
func (c *Client) ListUsers(ctx context.Context, p *ListParams) (*ListUsersResponse, error)
ListUsers lists users with pagination.
func (*Client) Login ¶
func (c *Client) Login(ctx context.Context, opts *LoginOptions) error
Login authenticates the user with the provided email and password. On success, it stores the returned access token in the client.
func (*Client) Refresh ¶ added in v0.3.0
Refresh refreshes the authentication token. It stores the new token in the client.
func (*Client) RestoreBackup ¶ added in v1.1.0
func (c *Client) RestoreBackup(ctx context.Context, p *RestoreBackupParams) error
func (*Client) SetToken ¶ added in v0.2.0
SetToken sets the API token to be used for authentication.
func (*Client) UpdateAuditLogRetentionPolicy ¶ added in v0.2.0
func (c *Client) UpdateAuditLogRetentionPolicy(ctx context.Context, opts *UpdateAuditLogsRetentionPolicyOptions) error
UpdateAuditLogRetentionPolicy updates the audit log retention policy.
func (*Client) UpdateFlowReportsRetentionPolicy ¶ added in v1.4.0
func (c *Client) UpdateFlowReportsRetentionPolicy(ctx context.Context, opts *UpdateFlowReportsRetentionPolicyOptions) error
UpdateFlowReportsRetentionPolicy updates the flow reports retention policy.
func (*Client) UpdateNATInfo ¶ added in v0.3.0
func (c *Client) UpdateNATInfo(ctx context.Context, opts *UpdateNATInfoOptions) error
UpdateNATInfo updates the Network Address Translation (NAT) configuration.
func (*Client) UpdateOperatorHomeNetwork ¶ added in v0.5.0
func (c *Client) UpdateOperatorHomeNetwork(ctx context.Context, opts *UpdateOperatorHomeNetworkOptions) error
UpdateOperatorHomeNetwork updates the operator's home network information (private key).
func (*Client) UpdateOperatorID ¶
func (c *Client) UpdateOperatorID(ctx context.Context, opts *UpdateOperatorIDOptions) error
UpdateOperatorID updates the operator's Mobile Country Code (MCC) and Mobile Network Code (MNC).
func (*Client) UpdateOperatorSlice ¶
func (c *Client) UpdateOperatorSlice(ctx context.Context, opts *UpdateOperatorSliceOptions) error
UpdateOperatorSlice updates the operator's slice information.
func (*Client) UpdateOperatorTracking ¶
func (c *Client) UpdateOperatorTracking(ctx context.Context, opts *UpdateOperatorTrackingOptions) error
UpdateOperatorTracking updates the operator's tracking information (supported TACs).
func (*Client) UpdateRadioEventRetentionPolicy ¶ added in v0.6.0
func (c *Client) UpdateRadioEventRetentionPolicy(ctx context.Context, opts *UpdateRadioEventsRetentionPolicyOptions) error
UpdateRadioEventRetentionPolicy updates the radio event retention policy.
func (*Client) UpdateUsageRetentionPolicy ¶ added in v0.6.0
func (c *Client) UpdateUsageRetentionPolicy(ctx context.Context, opts *UpdateUsageRetentionPolicyOptions) error
UpdateUsageRetentionPolicy updates the usage retention policy with the provided options.
type Config ¶
type Config struct {
// BaseURL contains the base URL where Ella Core is expected to be.
BaseURL string
// APIToken is the API token used for authentication.
APIToken string
// TLSConfig is an optional TLS configuration.
TLSConfig *tls.Config
}
Config allows the user to customize client behavior.
type ConnectionError ¶
type ConnectionError struct {
// contains filtered or unexported fields
}
ConnectionError represents a connection or communication error.
func (ConnectionError) Error ¶
func (e ConnectionError) Error() string
func (ConnectionError) Unwrap ¶
func (e ConnectionError) Unwrap() error
type CreateAPITokenOptions ¶ added in v0.2.0
type CreateAPITokenResponse ¶ added in v0.2.0
type CreateAPITokenResponse struct {
Token string `json:"token"`
}
type CreateBackupParams ¶ added in v1.1.0
type CreateBackupParams struct {
Path string
}
type CreateDataNetworkOptions ¶ added in v0.1.0
type CreatePolicyOptions ¶ added in v0.1.0
type CreateRouteOptions ¶
type CreateSubscriberOptions ¶
type CreateUserOptions ¶
type DataNetwork ¶ added in v0.1.0
type DeleteDataNetworkOptions ¶ added in v0.1.0
type DeleteDataNetworkOptions struct {
Name string `json:"name"`
}
type DeletePolicyOptions ¶ added in v0.1.0
type DeletePolicyOptions struct {
Name string `json:"name"`
}
type DeleteRouteOptions ¶
type DeleteRouteOptions struct {
ID int64 `json:"id"`
}
type DeleteSubscriberOptions ¶
type DeleteSubscriberOptions struct {
ID string `json:"id"`
}
type DeleteUserOptions ¶
type DeleteUserOptions struct {
Email string `json:"email"`
}
type FlowReport ¶ added in v1.4.0
type FlowReport struct {
ID int `json:"id"`
SubscriberID string `json:"subscriber_id"`
SourceIP string `json:"source_ip"`
DestinationIP string `json:"destination_ip"`
SourcePort uint16 `json:"source_port"`
DestinationPort uint16 `json:"destination_port"`
Protocol uint8 `json:"protocol"`
Packets uint64 `json:"packets"`
Bytes uint64 `json:"bytes"`
StartTime string `json:"start_time"`
EndTime string `json:"end_time"`
Direction string `json:"direction"`
}
type FlowReportIPStat ¶ added in v1.4.0
type FlowReportProtocolStat ¶ added in v1.4.0
type FlowReportStatsResponse ¶ added in v1.4.0
type FlowReportStatsResponse struct {
Protocols []FlowReportProtocolStat `json:"protocols"`
TopDestinationsUplink []FlowReportIPStat `json:"top_destinations_uplink"`
}
type GenerateSupportBundleParams ¶ added in v1.5.0
type GenerateSupportBundleParams struct {
// Path is the destination file path where the downloaded bundle will be saved.
Path string
}
type GetAuditLogsRetentionPolicy ¶ added in v0.2.0
type GetAuditLogsRetentionPolicy struct {
Days int `json:"days"`
}
type GetDataNetworkOptions ¶ added in v0.1.0
type GetDataNetworkOptions struct {
Name string `json:"name"`
}
type GetFlowReportsRetentionPolicy ¶ added in v1.4.0
type GetFlowReportsRetentionPolicy struct {
Days int `json:"days"`
}
type GetNATInfoResponse ¶ added in v0.3.0
type GetNATInfoResponse struct {
Enabled bool `json:"enabled,omitempty"`
}
type GetOperatorHomeNetworkResponse ¶
type GetOperatorHomeNetworkResponse struct {
PublicKey string `json:"publicKey,omitempty"`
}
type GetOperatorIDResponse ¶
type GetOperatorTrackingResponse ¶
type GetOperatorTrackingResponse struct {
SupportedTacs []string `json:"supportedTacs,omitempty"`
}
type GetPolicyOptions ¶ added in v0.1.0
type GetPolicyOptions struct {
Name string `json:"name"`
}
type GetRadioEventsRetentionPolicy ¶ added in v0.6.0
type GetRadioEventsRetentionPolicy struct {
Days int `json:"days"`
}
type GetRadioOptions ¶
type GetRadioOptions struct {
Name string `json:"name"`
}
type GetRouteOptions ¶
type GetRouteOptions struct {
ID int64 `json:"id"`
}
type GetSubscriberCredentialsOptions ¶ added in v1.5.0
type GetSubscriberCredentialsOptions struct {
ID string `json:"id"`
}
GetSubscriberCredentialsOptions holds the parameters for GetSubscriberCredentials.
type GetSubscriberOptions ¶
type GetSubscriberOptions struct {
ID string `json:"id"`
}
type GetUsageRetentionPolicy ¶ added in v0.6.0
type GetUsageRetentionPolicy struct {
Days int `json:"days"`
}
type GroupedFlowReportsResponse ¶ added in v1.4.0
type GroupedFlowReportsResponse []map[string][]FlowReport
type InitializeOptions ¶ added in v0.4.0
type InitializeResponseResult ¶ added in v1.3.0
type ListAPITokensResponse ¶ added in v0.3.0
type ListAuditLogsParams ¶ added in v1.5.0
type ListAuditLogsParams struct {
Page int `json:"page"`
PerPage int `json:"per_page"`
Actor string `json:"actor"`
Start string `json:"start"`
End string `json:"end"`
}
ListAuditLogsParams contains all filter and pagination options for listing audit logs.
type ListAuditLogsResponse ¶ added in v0.3.0
type ListDataNetworksResponse ¶ added in v0.3.0
type ListDataNetworksResponse struct {
Items []DataNetwork `json:"items"`
Page int `json:"page"`
PerPage int `json:"per_page"`
TotalCount int `json:"total_count"`
}
type ListFlowReportsParams ¶ added in v1.4.0
type ListFlowReportsParams struct {
Page int `json:"page"`
PerPage int `json:"per_page"`
SubscriberID string `json:"subscriber_id"`
Protocol string `json:"protocol"`
Source string `json:"source"`
Destination string `json:"destination"`
Direction string `json:"direction"`
Start string `json:"start"`
End string `json:"end"`
}
type ListFlowReportsResponse ¶ added in v1.4.0
type ListFlowReportsResponse struct {
Items []FlowReport `json:"items"`
Page int `json:"page"`
PerPage int `json:"per_page"`
TotalCount int `json:"total_count"`
}
type ListParams ¶ added in v0.3.0
type ListPoliciesResponse ¶ added in v0.3.0
type ListRadioEventsParams ¶ added in v0.6.0
type ListRadioEventsResponse ¶ added in v0.6.0
type ListRadioEventsResponse struct {
Items []RadioEvent `json:"items"`
Page int `json:"page"`
PerPage int `json:"per_page"`
TotalCount int `json:"total_count"`
}
type ListRadiosResponse ¶ added in v0.3.0
type ListRoutesResponse ¶ added in v0.3.0
type ListSubscribersResponse ¶ added in v0.3.0
type ListSubscribersResponse struct {
Items []Subscriber `json:"items"`
Page int `json:"page"`
PerPage int `json:"per_page"`
TotalCount int `json:"total_count"`
}
type ListUsageParams ¶ added in v0.6.0
type ListUsageResponse ¶ added in v0.6.0
type ListUsageResponse []map[string]SubscriberUsage
type ListUsersResponse ¶ added in v0.3.0
type LoginOptions ¶
type LoginResponseResult ¶
type Operator ¶
type Operator struct {
ID GetOperatorIDResponse `json:"id,omitempty"`
Slice GetOperatorSliceResponse `json:"slice,omitempty"`
Tracking GetOperatorTrackingResponse `json:"tracking,omitempty"`
HomeNetwork GetOperatorHomeNetworkResponse `json:"homeNetwork,omitempty"`
}
type Radio ¶
type Radio struct {
Name string `json:"name"`
ID string `json:"id"`
Address string `json:"address"`
SupportedTAIs []SupportedTAI `json:"supported_tais"`
}
type RadioEvent ¶ added in v0.6.0
type RadioEventContent ¶ added in v0.6.0
type RefreshResponseResult ¶ added in v0.3.0
type RefreshResponseResult struct {
Token string `json:"token"`
}
type RequestError ¶
type RequestError struct {
// contains filtered or unexported fields
}
RequestError is returned when there's an error processing the request.
func (RequestError) Error ¶
func (e RequestError) Error() string
type RequestOptions ¶
type RequestResponse ¶
type RequestResponse struct {
StatusCode int
Headers http.Header
// Result can contain request specific JSON data. The result can be
// unmarshalled into the expected type using the DecodeResult method.
Result []byte
// Body is only set for request type RawRequest.
Body io.ReadCloser
}
func (*RequestResponse) DecodeResult ¶
func (resp *RequestResponse) DecodeResult(result any) error
DecodeResult decodes the endpoint-specific result payload that is included as part of sync and async request responses.
type Requester ¶
type Requester interface {
// Do performs the HTTP transaction using the provided options.
Do(ctx context.Context, opts *RequestOptions) (*RequestResponse, error)
}
type RestoreBackupParams ¶ added in v1.1.0
type RestoreBackupParams struct {
Path string
}
type Subscriber ¶
type Subscriber struct {
Imsi string `json:"imsi"`
Opc string `json:"opc"` // Deprecated: use GetSubscriberCredentials instead.
SequenceNumber string `json:"sequenceNumber"` // Deprecated: use GetSubscriberCredentials instead.
Key string `json:"key"` // Deprecated: use GetSubscriberCredentials instead.
PolicyName string `json:"policyName"`
Status SubscriberStatus `json:"status"`
}
Subscriber is the summary representation returned by the list endpoint.
type SubscriberCredentials ¶ added in v1.5.0
type SubscriberCredentials struct {
Key string `json:"key"`
Opc string `json:"opc"`
SequenceNumber string `json:"sequenceNumber"`
}
SubscriberCredentials contains the authentication credentials for a subscriber.
type SubscriberDetail ¶ added in v1.5.0
type SubscriberDetail struct {
Imsi string `json:"imsi"`
Opc string `json:"opc"` // Deprecated: use GetSubscriberCredentials instead.
SequenceNumber string `json:"sequenceNumber"` // Deprecated: use GetSubscriberCredentials instead.
Key string `json:"key"` // Deprecated: use GetSubscriberCredentials instead.
PolicyName string `json:"policyName"`
Status SubscriberDetailStatus `json:"status"`
}
SubscriberDetail is the full representation returned by the get-single endpoint.
type SubscriberDetailStatus ¶ added in v1.5.0
type SubscriberDetailStatus struct {
Registered bool `json:"registered"`
IPAddress string `json:"ipAddress"`
Imei string `json:"imei"`
CipheringAlgorithm string `json:"cipheringAlgorithm"`
IntegrityAlgorithm string `json:"integrityAlgorithm"`
LastSeenAt string `json:"lastSeenAt,omitempty"`
LastSeenRadio string `json:"lastSeenRadio,omitempty"`
}
SubscriberDetailStatus is the rich status returned by the get-single endpoint.
type SubscriberStatus ¶ added in v0.1.0
type SubscriberStatus struct {
Registered bool `json:"registered"`
IPAddress string `json:"ipAddress"`
}
SubscriberStatus is the lightweight status returned by the list endpoint.
type SubscriberUsage ¶ added in v0.6.0
type SupportedTAI ¶
type UpdateAuditLogsRetentionPolicyOptions ¶ added in v0.2.0
type UpdateAuditLogsRetentionPolicyOptions struct {
Days int `json:"days"`
}
type UpdateFlowReportsRetentionPolicyOptions ¶ added in v1.4.0
type UpdateFlowReportsRetentionPolicyOptions struct {
Days int `json:"days"`
}
type UpdateNATInfoOptions ¶ added in v0.3.0
type UpdateNATInfoOptions struct {
Enabled bool `json:"enabled"`
}
type UpdateOperatorHomeNetworkOptions ¶ added in v0.5.0
type UpdateOperatorHomeNetworkOptions struct {
PrivateKey string
}
type UpdateOperatorIDOptions ¶
type UpdateOperatorTrackingOptions ¶
type UpdateOperatorTrackingOptions struct {
SupportedTacs []string
}
type UpdateRadioEventsRetentionPolicyOptions ¶ added in v0.6.0
type UpdateRadioEventsRetentionPolicyOptions struct {
Days int `json:"days"`
}
type UpdateUsageRetentionPolicyOptions ¶ added in v0.6.0
type UpdateUsageRetentionPolicyOptions struct {
Days int `json:"days"`
}